@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w -I../lib/
 use strict;
-use Remote::Use config => 'rsyncconfig';
+use Remote::Use config => 'rsyncconfigweb';
 use Trivial;
 
 Trivial::hello();
